# frozen_string_literal: true

# checker Api::Dmo::HermesController avant d'ajouter des methodes
module Hermes
  module Api
    module Dmo
      class HousingApplicationsController < Hermes::Api::Dmo::ApplicationController
        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $gt
          $gte
          $lt
          $lte
          $regex
        ]
        
        ACCEPTABLE_PARAMS = %w[
          ids
          housing_request_id
          housing_offer_id
          epci
          max_date
          applicated_at
          effort_rate
          status
          status_updated_at
          visit_conducted_date
          visit_status
          visit_status_updated_at
lessor_event_informations
last_status_update_date

        ]
        
        REGEX_PARAMS = %w[
        ]
        
        MUTATE_PARAMS = %i[
          housing_request_id
          housing_offer_id
          epci
          max_date
          status
          visit_status
          visit_conducted_date
          lessor_event_informations
          last_status_update_date
        ]
        
        mutate_params_only(*MUTATE_PARAMS)
        
        def index
          acceptable_params *ACCEPTABLE_PARAMS
          regex_params *REGEX_PARAMS
          valid_operators *VALID_OPERATORS
          super
        end
        
        def update_status
          nud = Hermes::Nud.find_by(unique_number: params["data"]["attributes"]["unique_number"])
          return render_json_error(:unprocessable_entity, :unique_number_not_found) if !nud
          housing_offer = Hermes::HousingOffer.find_by(external_ref: params["data"]["attributes"]["external_ref"])
          return render_json_error(:unprocessable_entity, :housing_offer_not_found) if !housing_offer
          @instance = Hermes::HousingApplication.find_by(housing_offer_id: housing_offer.id, housing_request: nud.housing_request_id)
          return render_json_error(:not_found, :object_not_found) unless @instance
          return render_json_error(:unprocessable_entity, :not_writers) unless @instance.reload && @instance.writable_by?(@user)
          check_params_and_update
        end
      end
    end
  end
end
